/*
 * Copyright (c) 2009, Mason Green (zzzzrrr)
 * http://www.dsource.org/projects/openmelee
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * * Neither the name of the polygonal nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
module openmelee.ships.orz;

import blaze.dynamics.bzBody : bzBody;
import blaze.bzWorld: bzWorld;
import blaze.dynamics.bzBodyDef;
import blaze.collision.shapes.bzPolygon : bzPolyDef;
import blaze.common.bzMath: bzVec2, PI;

import openmelee.ships.ship;

// UrQuan Dreadnought
class Orz : Ship
{

    float scale = 0.025;

    this(bzWorld world) {
        
        super(world);
        engineForce = bzVec2(500, 0);
        turnForce = bzVec2(0, 5000);
        rightTurnPoint = bzVec2(-0.5, 0);
        leftTurnPoint = bzVec2(0.5, 0);

        auto bodyDef = new bzBodyDef;
        //bodyDef.isBullet = true;
        bodyDef.position = bzVec2(20,15);
        bodyDef.angle = PI/2;
        bodyDef.allowFreeze = false;
        bodyDef.allowSleep = false;

        rBody = world.createBody(bodyDef);
        float density = 5.0f;

        // Body
        auto b = new bzPolyDef(density);
        b.vertices.length = 4;
        b.vertices[0] = bzVec2(42,14) * scale;
        b.vertices[1] = bzVec2(-28,21) * scale;
        b.vertices[2] = bzVec2(-28,-28) * scale;
        b.vertices[3] = bzVec2(42,-21) * scale;
        shapes.add(rBody.createShape(b));

        // Top Wing
        auto tWing = new bzPolyDef(density);
        tWing.vertices.length = 5;
        tWing.vertices[4] = bzVec2(-28,21) * scale;
        tWing.vertices[3] = bzVec2(-70,63) * scale;
        tWing.vertices[2] = bzVec2(-49,63) * scale;
        tWing.vertices[1] = bzVec2(70,14) * scale;
        tWing.vertices[0] = bzVec2(42,14) * scale;
        shapes.add(rBody.createShape(tWing));

        // Bottom Wing
        auto bWing = new bzPolyDef(density);
        bWing.vertices.length = 5;
        bWing.vertices[0] = bzVec2(-28,-28) * scale;
        bWing.vertices[1] = bzVec2(-70,-63) * scale;
        bWing.vertices[2] = bzVec2(-49,-63) * scale;
        bWing.vertices[3] = bzVec2(70,-21) * scale;
        bWing.vertices[4] = bzVec2(42,-21) * scale;
        shapes.add(rBody.createShape(bWing));

        rBody.setMassFromShapes();
        setPlanetGravity();
        calcRadius();
      }
}
